@@ -35,7 +35,7 @@
 
 use eyre::Result;
 use futures::future::join_all;
-use safe_network::routing::{
+use safe_network::node::routing::{
     create_test_used_space_and_root_storage, Config, Event, EventStream, Routing,
 };
 use std::{
